ORIGPWD="$PWD"
cd "$MUSL_CC_BASE"
MUSL_CC_BASE="$PWD"
export MUSL_CC_BASE
cd "$ORIGPWD"
unset ORIGPWD

set -ex


if [ ! -e config.sh ]
then
    echo 'Create a config.sh file.'
    exit 1
fi

# ADACORE GPL 2016
GCC_INTERFACE_URL=http://mirrors.cdn.adacore.com/art/57399232c7a447658e0aff7d
GCC_URL=http://mirrors.cdn.adacore.com/art/573992d4c7a447658d00e1db
GNAT_GPL_URL=http://mirrors.cdn.adacore.com/art/57399304c7a447658e0aff7f

# xmlada / gprbuild in 2016, do not contain bootstrap script, so don't use
#XMLADA=http://mirrors.cdn.adacore.com/art/57399978c7a447658e0affc0
#GPRBUILD=http://mirrors.cdn.adacore.com/art/57399662c7a447658e0affa8

#use gprbuild from 2017
#XMLADA=http://mirrors.cdn.adacore.com/art/591aeb88c7a4473fcbb154f8
#GPRBUILD=http://mirrors.cdn.adacore.com/art/591c45e2c7a447af2deecff7


die() {
    echo "$@"
    exit 1
}

fetch() {
    if [ ! -e "$MUSL_CC_BASE/tarballs/$2" ]
    then
        wget -O "$MUSL_CC_BASE/tarballs/$2.part" -c "$1"
        mv "$MUSL_CC_BASE/tarballs/$2.part" "$MUSL_CC_BASE/tarballs/$2"
    fi
    return 0
}

check() {
   if [ -e "$MUSL_CC_BASE/hashes/$1.hash" ]
   then
	   (cd "$MUSL_CC_BASE/tarballs" && sha512sum --check "$MUSL_CC_BASE/hashes/$1.hash") || exit -1
   fi
   return 0
}


extract() {
    if [ ! -e "$2/extracted" ]
    then
        tar xf "$MUSL_CC_BASE/tarballs/$1" ||
            tar Jxf "$MUSL_CC_BASE/tarballs/$1" ||
            tar jxf "$MUSL_CC_BASE/tarballs/$1" ||
            tar zxf "$MUSL_CC_BASE/tarballs/$1"
        mkdir -p "$2"
        touch "$2/extracted"
    fi
}

stripfileext() {
	case "$1" in
		*.tar.*) printf "%s" "$1"| sed 's/\.tar\.[0-9a-z]*$//' ;;
		*) basename "$1" | sed 's/\..*//' ;;
	esac
}

fetchextract() {
    baseurl="$1"
    dir="$2"
    fn="$2""$3"

    fetch "$baseurl" "$fn"
    check "$fn"
    extract "$fn" "$dir"
}


download_adacore() {
    fetchextract $GCC_INTERFACE_URL  gcc-interface-4.9-gpl-2016-src .tar.gz
    fetchextract $GCC_URL  gcc-4.9-gpl-2016-src .tar.gz 
    fetchextract $GNAT_GPL_URL gnat-gpl-2016-src .tar.gz 
}

merge_and_create_tar() {
	# we make the adacore gpl a fake gcc-4.9.adacore2016 FSF gcc
	# we then put this gcc-4.9.adacore2016 where the rest of the machinery
	# expects it and do the build as it was
	if [ ! -e "$MUSL_CC_BASE/tarballs/gcc-4.9.adacore2016.tar.bz2" ]
	then
  	 cp -R gcc-4.9-gpl-2016-src/ gcc-4.9.adacore2016
	 cp -R gnat-gpl-2016-src/src/ada gcc-4.9.adacore2016/gcc/
	 cp -R gcc-interface-4.9-gpl-2016-src gcc-4.9.adacore2016/gcc/ada/gcc-interface
	 tar -cf "$MUSL_CC_BASE/tarballs/gcc-4.9.adacore2016.tar" gcc-4.9.adacore2016	
	 bzip2 "$MUSL_CC_BASE/tarballs/gcc-4.9.adacore2016.tar"
	fi
}

download_adacore
merge_and_create_tar
